pwman Package — pwman3 0.6 documentation

### Navigation

- index
- modules |
- pwman3 0.6 documentation »

# pwman Package

## `pwman` Package

`pwman.__init__.` `get_conf`(args)

`pwman.__init__.` `get_conf_options`(args, OSX)

`pwman.__init__.` `get_db_version`(config, args)

`pwman.__init__.` `parser_options`(formatter_class=<class 'argparse.HelpFormatter'>)

`pwman.__init__.` `set_db`(args, configp)

`pwman.__init__.` `set_umask`(configp)

`pwman.__init__.` `set_win_colors`(config)

`pwman.__init__.` `set_xsel`(configp, OSX)

`pwman.__init__.` `which`(cmd)

## Subpackages

- data Package
  - `convertdb` Module
  - `database` Module
  - `factory` Module
  - `nodes` Module
  - Subpackages
    - drivers Package
      - `sqlite` Module
- exchange Package
  - `importer` Module
- ui Package
  - `ui` Package
  - `baseui` Module
  - `cli` Module
  - `mac` Module
  - `tools` Module
  - `win` Module
- util Package
  - `callback` Module
  - `config` Module
  - `crypto_engine` Module

### Navigation

- index
- modules |
- pwman3 0.6 documentation »